SyncResult class sealed

Result returned after a transport attempts to send one operation.

Implementers

Constructors

SyncResult.conflict({required String message, Object? local, Object? remote})
const
factory
SyncResult.failure(SyncFailure failure)
const
factory
SyncResult.success({Object? data})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited