fire method
void
fire()
Runs the callback once if the timer is still active.
Implementation
void fire() {
if (!_isActive) {
return;
}
_isActive = false;
_tick += 1;
_callback();
}
Runs the callback once if the timer is still active.
void fire() {
if (!_isActive) {
return;
}
_isActive = false;
_tick += 1;
_callback();
}