FakeSyncTransport class
In-memory transport for application tests.
Records every operation passed to send in sent, then answers with FakeSyncTransportHandler when one is given, or with success otherwise.
- Implemented types
Constructors
- FakeSyncTransport([FakeSyncTransportHandler? handler])
-
Creates a fake transport that responds using
handler.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sent
→ List<
SyncOperation> -
Operations passed to send, in send order.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
SyncOperation operation) → Future< SyncResult> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited